/*
     This file is part of GNUnet
     (C) 2001, 2002 Christian Grothoff (and other contributing authors)

     GNUnet is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published
     by the Free Software Foundation; either version 2, or (at your
     option) any later version.

     GNUnet is distributed in the hope that it will be useful, but
     WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     General Public License for more details.

     You should have received a copy of the GNU General Public License
     along with GNUnet; see the file COPYING.  If not, write to the
     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
*/

/**
 * @file include/checksum.h
 * @author Krista Bennett
 *
 * These functions deal with CRC32 checksums
 * (plus some other trivial helper functions
 * that do not fit anywhere else).
 **/

#ifndef CHECKSUM_H
#define CHECKSUM_H

#include "config.h"
#include "crc32.h"

/**
 * Compute the CRC32 checksum for the first len
 * bytes of the buffer.
 *
 * @param buf the data over which we're taking the CRC
 * @param len the length of the buffer in bytes
 * @return the resulting CRC32 checksum 
 **/
int crc32N(void * buf, int len);

/**
 * Produce a random value.
 *
 * @param i the upper limit (exclusive) for the random number
 * @return a random value in the interval [0,i[. 
 **/
int randomi(int i);

/**
 * Get an array with a random permutation of the
 * numbers 0...n-1.
 * @param n the size of the array
 * @return the permutation array (allocated from heap)
 **/
int * permute(int n);

/**
 * Convert a long-long to host-byte-order.
 * @param n the value in network byte order
 * @return the same value in host byte order
 **/
unsigned long long ntohll(unsigned long long n);

/**
 * Convert a long long to network-byte-order.
 * @param n the value in host byte order
 * @return the same value in network byte order
 **/
unsigned long long htonll(unsigned long long n);

#endif

/* end of checksum.h */
